==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/PolarLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarLineSeriesDescription } from "./PolarLineSeriesDescription";
/**
 * @hidden
 */
export let PolarLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarLineSeriesDescriptionMetadata.a == null) {
                PolarLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarLineSeriesDescriptionMetadata.c(PolarLineSeriesDescriptionMetadata.a);
            }
            if (a.j(PolarLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(PolarLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            PolarLineSeriesDescriptionMetadata.b(a);
            a.aa("PolarLineSeries", () => new PolarLineSeriesDescription());
            a.z("PolarLineSeries", PolarLineSeriesDescriptionMetadata.a);
        }
    }
    PolarLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarLineSeriesDescriptionMetadata, 'PolarLineSeriesDescriptionMetadata');
    PolarLineSeriesDescriptionMetadata.a = null;
    return PolarLineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PolarLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarLineSeriesDescription } from "./PolarLineSeriesDescription";
/**
 * @hidden
 */
export let PolarLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarLineSeriesDescriptionMetadata.a == null) {
                PolarLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarLineSeriesDescriptionMetadata.c(PolarLineSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(PolarLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            PolarLineSeriesDescriptionMetadata.b(a);
            a.ac("PolarLineSeries", () => new PolarLineSeriesDescription());
            a.ab("PolarLineSeries", PolarLineSeriesDescriptionMetadata.a);
        }
    }
    PolarLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarLineSeriesDescriptionMetadata, 'PolarLineSeriesDescriptionMetadata');
    PolarLineSeriesDescriptionMetadata.a = null;
    return PolarLineSeriesDescriptionMetadata;
})();
